<?php

namespace Drupal\poll_private\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\poll_private\PollPrivateTokenStorage;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Url;

class PollPrivateTokenController extends ControllerBase {

  protected $tokenStorage;

  public function __construct(PollPrivateTokenStorage $tokenStorage) {
    $this->tokenStorage = $tokenStorage;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('poll_private.token_storage')
    );
  }

  public function resend($token_id) {
    $token = $this->tokenStorage->load($token_id);
    $poll = Poll::load($token->poll_id);

    $mailManager = \Drupal::service('plugin.manager.mail');
    $url = Url::fromRoute('entity.poll.canonical', ['poll' => $token->poll_id], [
      'absolute' => TRUE,
      'query' => ['token' => $token->token],
    ])->toString();

    $params = [
      'subject' => $this->t('Your access to private poll: @title', ['@title' => $poll->label()]),
      'body' => [
        $this->t('Your access token has been resent.'),
        $this->t('Poll title: @title', ['@title' => $poll->label()]),
        $this->t('Your access token: @token', ['@token' => $token->token]),
        $this->t('Access link: @link', ['@link' => $url]),
      ],
    ];

    $mailManager->mail('poll_private', 'token', $token->email, 'en', $params);

    $this->messenger()->addStatus($this->t('Token has been resent to @email.', ['@email' => $token->email]));
    return $this->redirect('poll.private', ['poll' => $token->poll_id]);
  }
}