<?php

namespace Drupal\poll_private\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\poll\Entity\Poll;
use Symfony\Component\HttpFoundation\Request;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

class PollPrivateViewController extends ControllerBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Constructs a new PollPrivateViewController.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  public function view(Poll $poll, Request $request) {
    // Verificar si es encuesta privada
    $is_private = $this->isPrivatePoll($poll->id());
    $token = $request->query->get('token');

    // Si es privada pero no hay token, denegar acceso
    if ($is_private && !$token) {
      return [
        '#markup' => $this->t('This is a private poll. You need an access token.'),
      ];
    }

    // Verificar token válido
    if ($is_private && $token) {
      $token_valid = $this->validateToken($poll->id(), $token);
      
      if (!$token_valid) {
        return [
          '#markup' => $this->t('Invalid access token.'),
        ];
      }

      // Verificar si ya votó
      if ($this->hasUserVoted($poll->id(), $token)) {
        return [
          '#theme' => 'poll_private_already_voted',
          '#poll' => $poll,
        ];
      }
    }

    $view_builder = $this->entityTypeManager->getViewBuilder('poll');
    return $view_builder->view($poll, 'full');
  }

  protected function isPrivatePoll($poll_id) {
    return (bool) \Drupal::database()->select('poll_private_tokens', 'ppt')
      ->condition('poll_id', $poll_id)
      ->countQuery()
      ->execute()
      ->fetchField();
  }

  protected function validateToken($poll_id, $token) {
    return (bool) \Drupal::database()->select('poll_private_tokens', 'ppt')
      ->condition('poll_id', $poll_id)
      ->condition('token', $token)
      ->condition('used', 0)
      ->countQuery()
      ->execute()
      ->fetchField();
  }

  protected function hasUserVoted($poll_id, $token) {
    return (bool) \Drupal::database()->select('poll_private_tokens', 'ppt')
      ->condition('poll_id', $poll_id)
      ->condition('token', $token)
      ->condition('used', 1)
      ->countQuery()
      ->execute()
      ->fetchField();
  }
}