<?php

namespace Drupal\poll_private\Form;

use Drupal\Core\Form\ConfirmFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Drupal\poll_private\PollPrivateTokenStorage;
use Symfony\Component\DependencyInjection\ContainerInterface;

class PollPrivateTokenDeleteForm extends ConfirmFormBase {

  protected $tokenStorage;
  protected $token;

  public function __construct(PollPrivateTokenStorage $tokenStorage) {
    $this->tokenStorage = $tokenStorage;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('poll_private.token_storage')
    );
  }

  public function getFormId() {
    return 'poll_private_token_delete_form';
  }

  public function getQuestion() {
    return $this->t('Are you sure you want to delete this access token?');
  }

  public function getCancelUrl() {
    $poll_id = $this->token->poll_id;
    return Url::fromRoute('poll.private', ['poll' => $poll_id]);
  }

  public function buildForm(array $form, FormStateInterface $form_state, $token_id = NULL) {
    $this->token = $this->tokenStorage->load($token_id);
    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->tokenStorage->delete($this->token->id);
    $this->messenger()->addStatus($this->t('Token has been deleted.'));
    $form_state->setRedirectUrl($this->getCancelUrl());
  }
}